@@ -569,11 +569,14 @@ class GeneralizedTemporal(GeneralizedTemporalArray):
             scores_raw = mne.decoding.cross_val_multiscore(self._decoder, X, y,
                                                            cv=cv)
 
-        self._decoder.fit(X, y)
-        weights = mne.decoding.get_coef(self._decoder, 'patterns_',
-                                        inverse_transform=True)
-        if weights.ndim == 3:
-            weights = numpy.average(weights, axis=1)
+        if hasattr(self._decoder, 'patterns_'):
+            self._decoder.fit(X, y)
+            weights = mne.decoding.get_coef(self._decoder, 'patterns_',
+                                            inverse_transform=True)
+            if weights.ndim == 3:
+                weights = numpy.average(weights, axis=1)
+        else:
+            weights = None
 
         super(GeneralizedTemporal, self).__init__(scores_raw=scores_raw,
                                                   scoring_name=scoring,
